sync

package
v1.4.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrSyncAlreadyRunning = errors.New("sync is already running")

Functions

func NewSyncAlreadyRunningError

func NewSyncAlreadyRunningError(name string) error

Types

type ContainerSyncJob

type ContainerSyncJob struct {
	// contains filtered or unexported fields
}

ContainerSyncJob writes container information to the repository. Implements cron.Job interface required by the Cron scheduler

func NewContainerSyncJob

func NewContainerSyncJob(containerDtoLister listers.ContainerBulkDtoLister, repository repository.Repository, appNameExcludeList []string) *ContainerSyncJob

NewContainerSyncJob creates a new ContainerSyncJob

func (*ContainerSyncJob) Sync

func (s *ContainerSyncJob) Sync() error

Sync writes the current list of containers to the repository

type NodeSyncJob

type NodeSyncJob struct {
	// contains filtered or unexported fields
}

NodeSyncJob writes node information to the repository. Implements cron.Job interface required by the Cron scheduler

func NewNodeSyncJob

func NewNodeSyncJob(nodeDtoLister listers.NodeBulkDtoLister, repository repository.Repository) *NodeSyncJob

NewNodeSyncJob creates a new NodeSyncJob

func (*NodeSyncJob) Sync

func (s *NodeSyncJob) Sync() error

Sync writes the current list of nodes to the repository

type Syncer

type Syncer interface {
	Sync() error
}

Syncer defines an interface with a Sync method

Jump to